@@ -3,7 +3,7 @@ from .week_tIme_window import WeekTimeWindow
 from .military_time import MilitaryTime
 from .time_window import TimeWindow
 from .weekday import WeekDay
-from .session_window import SessionWindow
+from .military_time_window import MilitaryTimeWindow
 
 __all__ = [
     "WeekTime",
@@ -11,5 +11,5 @@ __all__ = [
     "MilitaryTime",
     "TimeWindow",
     "WeekDay",
-    "SessionWindow",
+    "MilitaryTimeWindow",
 ]
