@@ -1,6 +1,6 @@
 from pytz import timezone, utc, BaseTzInfo
 
-from shuttl_time import WeekTime, WeekTimeWindow, SessionWindow
+from shuttl_time import WeekTime, WeekTimeWindow, MilitaryTimeWindow
 from shuttl_time.military_time import MilitaryTime
 from shuttl_time.weekday import WeekDay
 
@@ -30,10 +30,10 @@ def week_time_window_dm(start: WeekTime = None, end: WeekTime = None) -> WeekTim
     return WeekTimeWindow(start=start, end=end or start)
 
 
-def session_window_dm(
+def military_time_window_dm(
     from_time: int = 1000, to_time: int = 1200, timezone: BaseTzInfo = utc
-) -> SessionWindow:
-    return SessionWindow(
+) -> MilitaryTimeWindow:
+    return MilitaryTimeWindow(
         from_time=MilitaryTime(from_time, timezone),
         to_time=MilitaryTime(to_time, timezone),
     )
